# coding: utf-8

"""
    Spotii Notification API

    API for send sms/email messages  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@spotii.me
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import spotii_notification_client
from notification.sms_api import SmsApi  # noqa: E501
from spotii_notification_client.rest import ApiException


class TestSmsApi(unittest.TestCase):
    """SmsApi unit test stubs"""

    def setUp(self):
        self.api = notification.sms_api.SmsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_sms_messages_create(self):
        """Test case for sms_messages_create

        """
        pass


if __name__ == '__main__':
    unittest.main()
