# coding: utf-8

"""
    Spotii Notification API

    API for send sms/email messages  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@spotii.me
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import spotii_notification_client
from notification.message import Message  # noqa: E501
from spotii_notification_client.rest import ApiException


class TestMessage(unittest.TestCase):
    """Message unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMessage(self):
        """Test Message"""
        # FIXME: construct object with mandatory attributes with example values
        # model = spotii_notification_client.models.message.Message()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
